<?php

/**
 * Method hr_office_get_vacancy_permalink
 *
 * @param int $vacancy_id Id of current vacancy form
 * @param int $shortcode_id Id of current shortcode
 *
 * @return string
 */
function hr_office_get_vacancy_permalink( $vacancy_id, $shortcode_id ) {
	// Replace spaces and other characters in the title
	$replace_param_list = array( ' ', '(', ')', '-', '/' );
	$portalId           = get_post_meta( $shortcode_id, '_api_portal_id', true );
	$developerKey       = get_post_meta( $shortcode_id, '_api_developer_key', true );
	$languageId         = get_post_meta( $shortcode_id, '_api_language_id', true );

	$appdata = array(
		'portalId'     => get_post_meta( $shortcode_id, '_api_portal_id', true ),
		'developerKey' => get_post_meta( $shortcode_id, '_api_developer_key', true ),
		'languageId'   => get_post_meta( $shortcode_id, '_api_language_id', true ),
		'vacancyId'    => $vacancy_id,
	);

	$client    = new SoapClient( 'https://api.hroffice.nl/HROfficeCoreService.asmx?wsdl' );
	$resp      = $client->GetJobByIdAndLanguage( $appdata );
	$job_title = ( isset( $resp->GetJobByIdAndLanguageResult->Name ) ) ? $resp->GetJobByIdAndLanguageResult->Name : '';

	// Get the current page ID
	$current_page_id = get_post_meta( $shortcode_id, '_listing_page_selected', true );

	// Default URL structure
	$default_url     = get_permalink( $current_page_id ) . $vacancy_id . '-' . str_replace( $replace_param_list, '', $job_title ) . '-' . $shortcode_id;
	$final_permalink = $default_url;

	// Check if custom URL settings are enabled
	$custom_url_settings = get_post_meta( $shortcode_id, 'nls_custom_url_settings', true );
	if ( isset( $custom_url_settings['nls_enable_custom_url_structure'] ) && 'yes' === $custom_url_settings['nls_enable_custom_url_structure'] ) {
		// Get the job details

		$product = (array) $resp->GetJobByIdAndLanguageResult;

		if ( isset( $product['AvJobCustomFields']->AvJobCustomField ) ) {
			if ( isset( $product['AvJobCustomFields']->AvJobCustomField ) ) {
				$resp_live_filter     = $client->GetVacancyCustomFields( $appdata );
				$resp_filter_data     = $resp_live_filter->GetVacancyCustomFieldsResult->CustomFields->AvVacancyCustomField;
				$single_vac_filters   = $product['AvJobCustomFields']->AvJobCustomField;
				$searched_filter_indx = array_search( $custom_url_settings['nls_selected_url_filter'], array_column( $single_vac_filters, 'Code' ) );
				$found_filter         = $single_vac_filters[ $searched_filter_indx ];
				$found_filter_code    = $found_filter->Values->string;

				$search_indx_frm_all = array_search( $custom_url_settings['nls_selected_url_filter'], array_column( $resp_filter_data, 'Code' ) );

				$all_options = $resp_filter_data[ $search_indx_frm_all ]->ExtraData->SingleSelectDropDown->Options->AvVacancyCustomFiledOption;

				$option_indx = array_search( $found_filter_code, array_column( $all_options, 'Code' ) );

				$slug = sanitize_title( $all_options[ $option_indx ]->Name, '', false );
			} else {
				$slug = 'na';
			}

			$final_permalink = get_permalink( $current_page_id ) . "$slug/" . $product['Id'] . '/' . str_replace( $replace_param_list, '', $job_title ) . '-' . $shortcode_id;
		}
	}

	return $final_permalink;
}


add_shortcode( 'hr-office-vacancy-job-form', 'hr_office_individual_job_form' );

/**
 * Method hr_office_individual_job_form
 *
 * @param array $attr Array of arguments by user.
 *
 * @return string
 */
function hr_office_individual_job_form( $attr ) {
	$btn_text              = ( isset( $attr['btn_text'] ) ) ? $attr['btn_text'] : '';
	$form_title            = ( isset( $attr['form_title'] ) ) ? $attr['form_title'] : '';
	$plugin_license_status = get_option( 'hr_office_vacancy_plugin_license_status' );
	if ( $plugin_license_status != 'valid' ) {
		return '<h4 style="text-align: center;">' . __( 'Please activate the License first.', 'hr_office_vacancy_domain' ) . '</h4>';
	}
	$shortcode_id_post = ( isset( $attr['shortcode_id'] ) ) ? $attr['shortcode_id'] : '';
	if ( empty( $shortcode_id_post ) ) {
		return '<h4 style="text-align: center;">' . __( 'Please add shortcode ID.', 'hr_office_vacancy_domain' ) . '</h4>';
	}
	$vacancy_id = ( isset( $attr['vacancy_id'] ) ) ? $attr['vacancy_id'] : '';
	if ( empty( $vacancy_id ) ) {
		return '<h4 style="text-align: center;">' . __( 'Please add vacancy ID.', 'hr_office_vacancy_domain' ) . '</h4>';
	}

	$portal_id     = get_post_meta( $shortcode_id_post, '_api_portal_id', true );
	$developer_key = get_post_meta( $shortcode_id_post, '_api_developer_key', true );
	$language_id   = get_post_meta( $shortcode_id_post, '_api_language_id', true );

	$appdata = array(
		'portalId'         => $portal_id,
		'developerKey'     => $developer_key,
		'vacancyId'        => $vacancy_id,
		'keywords'         => '',
		'location'         => '',
		'categoryId'       => '',
		'educationLevelId' => '',
		'languageId'       => $language_id,
	);

	$client       = new SoapClient( 'https://api.hroffice.nl/HROfficeCoreService.asmx?wsdl' );
	$respform     = $client->GetApplicationByIdAndLanguage( $appdata );
	$respformdata = $respform->GetApplicationByIdAndLanguageResult;
	if ( isset( $respformdata->Title ) && '' !== trim( $respformdata->Title ) ) {
		$job_title = $respformdata->Title;
	} else {
		$has_multi_channels = get_post_meta( $shortcode_id_post, 'hro_multi_channel_creds', true );
		$has_multi_channels = ( '' !== $has_multi_channels && ! empty( $has_multi_channels ) ) ? $has_multi_channels : false;

		if ( false !== $has_multi_channels ) {
			foreach ( $has_multi_channels as $single_channel ) {
				$temp_appdata = array(
					'portalId'         => $single_channel['portal-id'],
					'vacancyId'        => $vacancy_id,
					'developerKey'     => $single_channel['dev-key'],
					'keywords'         => '',
					'location'         => '',
					'categoryId'       => '',
					'educationLevelId' => '',
					'languageId'       => $language_id,
				);

				$temp_client        = new SoapClient( 'https://api.hroffice.nl/HROfficeCoreService.asmx?wsdl' );
				$temp_resp          = $temp_client->GetApplicationByIdAndLanguage( $temp_appdata );
				$temp_resp_formdata = $temp_resp->GetApplicationByIdAndLanguageResult;

				if ( isset( $temp_resp_formdata->Title ) && ! '' !== trim( $temp_resp_formdata->Title ) ) {
					$respformdata = $temp_resp_formdata;
					$appdata      = $temp_appdata;
					$job_title    = $temp_resp_formdata->Title;
					$client       = $temp_client;
					break;
				}
			}
		}
	}
	$protocol                     = ( ( ! empty( $_SERVER['HTTPS'] ) && $_SERVER['HTTPS'] != 'off' ) || $_SERVER['SERVER_PORT'] == 443 ) ? 'https://' : 'http://';
	$current_url                  = hr_office_get_vacancy_permalink( $vacancy_id, $shortcode_id_post );
	$apply_privacy_policy_text    = get_post_meta( $shortcode_id_post, '_job_apply_privacy_policy_text', true );
	$apply_privacy_policy_link    = get_post_meta( $shortcode_id_post, '_job_apply_privacy_policy_link', true );
	$apply_terms_text             = get_post_meta( $shortcode_id_post, '_job_apply_terms_text', true );
	$apply_form_title_text        = ( ! empty( $form_title ) ) ? $form_title : get_post_meta( $shortcode_id_post, '_job_apply_form_title_text', true );
	$apply_form_submit_text       = ( ! empty( $btn_text ) ) ? $btn_text : get_post_meta( $shortcode_id_post, '_job_apply_form_submit_text', true );
	$apply_term_condition_msg     = get_post_meta( $shortcode_id_post, '_job_apply_term_condition_msg', true );
	$apply_form_back_jobdesc_text = get_post_meta( $shortcode_id_post, '_job_apply_back_to_jobdetail_text', true );
	$list_job_title_color         = get_post_meta( $shortcode_id_post, '_list_job_title_color', true );
	$list_job_button_txt_color    = get_post_meta( $shortcode_id_post, '_list_job_button_txt_color', true );
	$list_job_button_bg_color     = get_post_meta( $shortcode_id_post, '_list_job_button_bg_color', true );
	$list_job_button_hover_color  = get_post_meta( $shortcode_id_post, '_list_job_button_hover_color', true );
	$form_unique_id               = 'hroffice-applyform-' . rand( 0, 1000000000 );

	ob_start();

	?>
	<div class="hroffice-listlayout-form vacancy-applyform-page">
		<div class="hr-office-form">
			<div class="container">
				<div class="text-container">
					<h2><?php echo $apply_form_title_text; ?></h2>
					
					<form id="<?php echo $form_unique_id; ?>" method="post" class="hroffice-applyform" enctype="multipart/form-data">                        
						<input type="hidden" name="shortcode_id" value="<?php echo $shortcode_id_post; ?>">
						<input type="hidden" name="vacancy_id" value="<?php echo $vacancy_id; ?>">
						<input type="hidden" name="thank-you-page-url" class="thank-you-page-url" value="<?php echo $current_url . '/apply/thankyou'; ?>">
						<?php
						$required_fields = array();
						if ( isset( $respformdata->ReactionFields->AvReactionFields ) && ! empty( $respformdata->ReactionFields->AvReactionFields ) ) :
							foreach ( $respformdata->ReactionFields->AvReactionFields as $fkey => $fval ) :
								$required_text = '';
								if ( isset( $fval->FieldIsRequired ) && $fval->FieldIsRequired == 1 ) {
									array_push( $required_fields, $fval->FieldName );
									$required_text = '*';
								}
								?>
								<div class="form-group ">
									<div class="left">
										<label for="">                                    
											<?php echo $fval->FieldText; ?><span class="field_required"> <?php echo $required_text; ?></span>
										</label>
									</div>                            
									<div class="right">
										<?php if ( $fval->FieldType == 1 ) : ?>    
											<input type="text" class="form-control" id="<?php echo $fval->FieldName; ?>" name="<?php echo $fval->FieldName; ?>" value="">
										<?php elseif ( $fval->FieldType == 5 ) : ?>
											<input type="number" min="0" class="form-control" id="<?php echo $fval->FieldName; ?>" name="<?php echo $fval->FieldName; ?>" value="">
										<?php elseif ( $fval->FieldType == 2 ) : ?>
											<select name="<?php echo $fval->FieldName; ?>" class="form-control" id="<?php echo $fval->FieldName; ?>">
												<?php foreach ( $fval->FieldValues->FieldValue as $selectval ) : ?>                                    
													<option value="<?php echo $selectval->ValueId; ?>"><?php echo $selectval->ValueText; ?></option>
												<?php endforeach; ?>                                        
											</select>
										<?php elseif ( $fval->FieldType == 7 ) : ?>
											<select name="<?php echo $fval->FieldName; ?>" class="form-control" id="<?php echo $fval->FieldName; ?>">
												<?php
												foreach ( $fval->FieldLanguagesValues->LanguageOptions as $selectkey => $selectval ) :
													if ( $selectval->ValueId == $language_id ) {
														foreach ( $fval->FieldLanguagesValues->LanguageOptions[ $selectkey ]->OptionsValue->LanguageValue as $selectlnval ) {
															?>
																						
															<option value="<?php echo $selectlnval->ValueId; ?>"><?php echo $selectlnval->ValueText; ?></option>
															<?php
														}
													}
												endforeach;
												?>
																						
											</select>    
										<?php elseif ( $fval->FieldType == 3 ) : ?>
											<textarea class="form-control textarea" name="<?php echo $fval->FieldName; ?>" id="<?php echo $fval->FieldName; ?>"></textarea>  
										<?php elseif ( $fval->FieldType == 6 ) : ?>
											<input type="date" class="form-control" id="<?php echo $fval->FieldName; ?>" name="<?php echo $fval->FieldName; ?>"> 
										<?php elseif ( $fval->FieldType == 8 || $fval->FieldType == 4 ) : ?>
											<input type="file" class="file-upload-btn" id="<?php echo $fval->FieldName; ?>" name="<?php echo $fval->FieldName; ?>">
											<input type="hidden" id="file_upload_nonce" name="file_upload_nonce" value="<?php echo wp_create_nonce( 'file_upload_nonce' ); ?>" >
											<span class="upload-response-<?php echo $fval->FieldName; ?>"></span>
										<?php else : ?>
											<input type="text" class="form-control" id="<?php echo $fval->FieldName; ?>" name="<?php echo $fval->FieldName; ?>" value="">
										<?php endif; ?>    
									</div>                            
								</div>
								<?php
							endforeach;
						endif;
						?>
						

						<?php
						if ( isset( $respformdata->QuestionsList ) ) :
							foreach ( $respformdata->QuestionsList->AvQuestionList as $qkey => $qval ) {
								$required_questn_text = '';

								if ( is_array( $respformdata->QuestionsList->AvQuestionList ) == 1 ) {
									$QuestionText     = $qval->QuestionText;
									$AnswerType       = $qval->AnswerType;
									$qestion_field_nm = 'question_' . $qval->QuestionId . '';
									$QuestionRequired = $qval->QuestionRequired;
									$AnswersList      = ( isset( $qval->AnswersList->AvAnswer ) ) ? $qval->AnswersList->AvAnswer : '';
									$onlyOneResult    = 'no';
								} else {
									$QuestionText     = $respformdata->QuestionsList->AvQuestionList->QuestionText;
									$AnswerType       = $respformdata->QuestionsList->AvQuestionList->AnswerType;
									$qestion_field_nm = 'question_' . $respformdata->QuestionsList->AvQuestionList->QuestionId . '';
									$QuestionRequired = $respformdata->QuestionsList->AvQuestionList->QuestionRequired;
									$AnswersList      = $respformdata->QuestionsList->AvQuestionList->AnswersList->AvAnswer;
									$onlyOneResult    = 'yes';
								}

								if ( $QuestionRequired == 1 ) {
									array_push( $required_fields, $qestion_field_nm );
									$required_questn_text = '*';
								}
								?>
							<div class="form-group ">
								<div class="left">
									<label for="">                                    
										<?php echo $QuestionText; ?><span class="field_required"> <?php echo $required_questn_text; ?></span>
									</label>
								</div>                            
								<div class="right">
									<?php if ( $AnswerType == 1 ) : ?>    
										<select name="<?php echo $qestion_field_nm; ?>" class="form-control" id="<?php echo $qestion_field_nm; ?>">
											<?php foreach ( $AnswersList as $selectvalq ) : ?>                                    
												<option value="<?php echo $selectvalq->AnswerId; ?>"><?php echo $selectvalq->AnswerText; ?></option>
											<?php endforeach; ?>                                        
										</select>
									<?php elseif ( $AnswerType == 4 ) : ?>
										<textarea class="form-control textarea" name="<?php echo $qestion_field_nm; ?>" id="<?php echo $qestion_field_nm; ?>"></textarea>
									<?php elseif ( $AnswerType == 2 || $AnswerType == 3 ) : ?>
										<?php
										$radioi = 0;
										foreach ( $AnswersList as $selectvalq ) :
											?>
																			
											<div>
												<input type="radio" class="" id="<?php echo $qestion_field_nm; ?>" 
																							<?php
																							if ( $radioi == 0 ) {
																								echo 'checked';}
																							?>
												name="<?php echo $qestion_field_nm; ?>" value="<?php echo $selectvalq->AnswerId; ?>"> 
												<?php echo $selectvalq->AnswerText; ?>
											</div>
											<?php
											++$radioi;
										endforeach;
										?>
																				
									<?php else : ?>
										<input type="text" class="form-control" id="<?php echo $qestion_field_nm; ?>" name="<?php echo $qestion_field_nm; ?>" value="">
									<?php endif; ?>    
								</div>                            
							</div>
								<?php
								if ( $onlyOneResult == 'yes' ) {
									break;
								}
							}
						endif;
						?>
												
						
						<div class="form-group">
							<div class="right">
								<label class="privacy-label">
									<input id="privacystatement" class="form-control-checkbox" name="privacystatement" type="checkbox" value="0" onclick="jQuery(this).attr('value', this.checked ? 'yes' : 0)"> <?php echo $apply_terms_text; ?> <a href="<?php echo get_permalink( $apply_privacy_policy_link ); ?>" target="_blank"><?php echo $apply_privacy_policy_text; ?></a>
								</label>
							</div>
						</div>
						<?php array_push( $required_fields, 'privacystatement' ); ?>
						
						<div class="form-group">
							<div class="actions">
								<button class="btn btn-apply" id="btn-apply"><?php echo $apply_form_submit_text; ?></button>
								<input type="hidden" id="apply_form_data_nonce" name="apply_form_data_nonce" value="<?php echo wp_create_nonce( 'apply_form_data_nonce' ); ?>">
								<img class="apply-btn-loader" style="display: none;" src="<?php echo HR_OFFICE_VACANCY_PLUGIN_DIR_URL; ?>assets/img/loader-4.gif">
							</div>
						</div>
						
					</form>
				</div>
			</div>
		</div>
	</div>
	<script>
	jQuery(document).ready(function() {
			var form = jQuery('#<?php echo $form_unique_id; ?>');
			var formId = form.attr('id');
			var formQueries = <?php echo json_encode( $required_fields ); ?>;
			var apply_term_condition_msg = '<?php echo $apply_term_condition_msg; ?>';

			form.find('#btn-apply').click(function(e) {
				e.preventDefault();
				var err = '';
				var clicked_button = jQuery(this);

				jQuery.each(formQueries, function(key, value) {
					var field = form.find('#' + value);
					if (!field.val()) {
						field.addClass('warning');
						err += 'yes';
					} else if (field.val() == 0) {
						field.addClass('warning');
						err += 'yes';
					} else {
						field.removeClass('warning');
						err += 'no';
					}

					var uploadResponse = form.find('.upload-response-' + value);
					if (uploadResponse.length > 0) {
						if (uploadResponse.html() != '') {
							err += 'yes';
						} else {
							err += 'no';
						}
					}
				});

				if (form.find('#privacystatement').val() == 0 && err.match(/yes/g) == 'yes') {
					alert(apply_term_condition_msg);
				}

				// referral cookie
				const reff_name = "hro_referral_code_" + <?php echo $vacancy_id; ?> + "=";
				const cDecoded = decodeURIComponent(document.cookie); //to be careful
				const cArr = cDecoded.split('; ');
				let referral_code;
				cArr.forEach(val => {
					if (val.indexOf(reff_name) === 0) referral_code = val.substring(reff_name.length);
				});

				// form submit
				if (err.indexOf("yes") == -1) {
					form.find('.apply-btn-loader').show();

					var ajaxurl = '<?php echo admin_url( 'admin-ajax.php' ); ?>';
					var formData = new FormData(document.getElementById(formId));
					formData.append('action', 'action_apply_form_data_send');
					formData.append('apply_form_data_nonce', form.find('#apply_form_data_nonce').val());
					if (typeof referral_code !== 'undefined') {
						formData.append('referral_code', referral_code);
					}
					
					var thankyouurl = form.find('.thank-you-page-url').val();
					jQuery.ajax({
						url: ajaxurl,
						type: 'POST',
						data: formData,
						processData: false,
						contentType: false,
						beforeSend: function() {
							// setting a timeout
							clicked_button.addClass('disabled');
						},
						success: function(response) {
							jQuery('.apply-btn-loader').hide();
							var returnedData = JSON.parse(response);
							if (returnedData.Code == 3) {
								var cookie_name = "<?php echo 'hro_referral_code_' . $vacancy_id; ?>";
								const d = new Date("2022-03-25");
								d.setTime(d.getTime() + (1 * 24 * 60 * 60 * 1000));
								let expires = "expires=" + d.toUTCString();
								document.cookie = cookie_name + "=;" + expires + ";path=/";

								window.location.href = thankyouurl;
							} else {
								alert(returnedData.Message);
							}
						}
					});
				}
			});

			// Form File upload event
			form.on('change', '.file-upload-btn', function(e) {
				e.preventDefault();
				var form_shortcode_id = form.find("input[name='shortcode_id']").val();
				var field_id = jQuery(this).attr("name");
				var formdata = new FormData();
				var files_data = jQuery(this);
				jQuery.each(jQuery(files_data), function(i, obj) {
					jQuery.each(obj.files, function(j, file) {
						formdata.append('files[' + j + ']', file);
					});
				});
				formdata.append('shortcode_id', form_shortcode_id);
				formdata.append('filenamedata', field_id);
				formdata.append('file_upload_nonce', form.find('#file_upload_nonce').val());
				formdata.append('action', 'hr_office_generic_form_upload_files');
				jQuery.ajax({
					type: "POST",
					url: '<?php echo admin_url( 'admin-ajax.php' ); ?>',
					data: formdata,
					contentType: false,
					processData: false,
					success: function(response) {
						form.find('.upload-response-' + field_id).html(response);
					}
				});
			});
	});
</script>

	<?php
	return ob_get_clean();
}
